@@ -45,52 +45,91 @@ function PMA_filterTracking(
  *
  * @param string $url_query    url query
  * @param int    $last_version last version
+ * @param string $db           database
+ * @param array  $selected     selected tables
+ * @param string $type         type of the table; table, view or both
  *
  * @return string
  */
 function PMA_getHtmlForDataDefinitionAndManipulationStatements($url_query,
-    $last_version
+    $last_version, $db, $selected, $type = 'both'
 ) {
-    $html = '<div id="div_create_version">';
-    $html .= '<form method="post" action="tbl_tracking.php' . $url_query . '">';
-    $html .= PMA_URL_getHiddenInputs($GLOBALS['db'], $GLOBALS['table']);
+    $html  = '<div id="div_create_version">';
+    $html .= '<form method="post" action="' . $url_query . '">';
+    $html .= PMA_URL_getHiddenInputs($db);
+    foreach ($selected as $selected_table) {
+        $html .= '<input type="hidden" name="selected[]"'
+            . ' value="' . htmlspecialchars($selected_table) . '" />';
+    }
+
     $html .= '<fieldset>';
     $html .= '<legend>';
-    $html .= sprintf(
-        __('Create version %1$s of %2$s'),
-        ($last_version + 1),
-        htmlspecialchars($GLOBALS['db'] . '.' . $GLOBALS['table'])
-    );
+    if (count($selected) == 1) {
+        $html .= sprintf(
+            __('Create version %1$s of %2$s'),
+            ($last_version + 1),
+            htmlspecialchars($db . '.' . $selected[0])
+        );
+    } else {
+        $html .= sprintf(__('Create version %1$s'), ($last_version + 1));
+    }
     $html .= '</legend>';
     $html .= '<input type="hidden" name="version" value="' . ($last_version + 1)
         . '" />';
     $html .= '<p>' . __('Track these data definition statements:')
         . '</p>';
-    $html .= '<input type="checkbox" name="alter_table" value="true"'
-        . (/*overload*/mb_stripos(
-            $GLOBALS['cfg']['Server']['tracking_default_statements'],
-            'ALTER TABLE'
-        ) !== false ? ' checked="checked"' : '')
-        . ' /> ALTER TABLE<br/>';
-    $html .= '<input type="checkbox" name="rename_table" value="true"'
-        . (/*overload*/mb_stripos(
-            $GLOBALS['cfg']['Server']['tracking_default_statements'],
-            'RENAME TABLE'
-        ) !== false ? ' checked="checked"' : '')
-        . ' /> RENAME TABLE<br/>';
-    $html .= '<input type="checkbox" name="create_table" value="true"'
-        . (/*overload*/mb_stripos(
-            $GLOBALS['cfg']['Server']['tracking_default_statements'],
-            'CREATE TABLE'
-        ) !== false ? ' checked="checked"' : '')
-        . ' /> CREATE TABLE<br/>';
-    $html .= '<input type="checkbox" name="drop_table" value="true"'
-        . (/*overload*/mb_stripos(
-            $GLOBALS['cfg']['Server']['tracking_default_statements'],
-            'DROP TABLE'
-        ) !== false ? ' checked="checked"' : '')
-        . ' /> DROP TABLE<br/>';
+
+    if ($type == 'both' || $type == 'table') {
+        $html .= '<input type="checkbox" name="alter_table" value="true"'
+            . (/*overload*/mb_stripos(
+                $GLOBALS['cfg']['Server']['tracking_default_statements'],
+                'ALTER TABLE'
+            ) !== false ? ' checked="checked"' : '')
+            . ' /> ALTER TABLE<br/>';
+        $html .= '<input type="checkbox" name="rename_table" value="true"'
+            . (/*overload*/mb_stripos(
+                $GLOBALS['cfg']['Server']['tracking_default_statements'],
+                'RENAME TABLE'
+            ) !== false ? ' checked="checked"' : '')
+            . ' /> RENAME TABLE<br/>';
+        $html .= '<input type="checkbox" name="create_table" value="true"'
+            . (/*overload*/mb_stripos(
+                $GLOBALS['cfg']['Server']['tracking_default_statements'],
+                'CREATE TABLE'
+            ) !== false ? ' checked="checked"' : '')
+            . ' /> CREATE TABLE<br/>';
+        $html .= '<input type="checkbox" name="drop_table" value="true"'
+            . (/*overload*/mb_stripos(
+                $GLOBALS['cfg']['Server']['tracking_default_statements'],
+                'DROP TABLE'
+            ) !== false ? ' checked="checked"' : '')
+            . ' /> DROP TABLE<br/>';
+    }
+    if ($type == 'both') {
+        $html .= '<br/>';
+    }
+    if ($type == 'both' || $type == 'view') {
+        $html .= '<input type="checkbox" name="alter_view" value="true"'
+            . (/*overload*/mb_stripos(
+                $GLOBALS['cfg']['Server']['tracking_default_statements'],
+                'ALTER VIEW'
+            ) !== false ? ' checked="checked"' : '')
+            . ' /> ALTER VIEW<br/>';
+        $html .= '<input type="checkbox" name="create_view" value="true"'
+            . (/*overload*/mb_stripos(
+                $GLOBALS['cfg']['Server']['tracking_default_statements'],
+                'CREATE VIEW'
+            ) !== false ? ' checked="checked"' : '')
+            . ' /> CREATE VIEW<br/>';
+        $html .= '<input type="checkbox" name="drop_view" value="true"'
+            . (/*overload*/mb_stripos(
+                $GLOBALS['cfg']['Server']['tracking_default_statements'],
+                'DROP VIEW'
+            ) !== false ? ' checked="checked"' : '')
+            . ' /> DROP VIEW<br/>';
+    }
     $html .= '<br/>';
+
     $html .= '<input type="checkbox" name="create_index" value="true"'
         . (/*overload*/mb_stripos(
             $GLOBALS['cfg']['Server']['tracking_default_statements'],
@@ -161,17 +200,17 @@ function PMA_getHtmlForActivateDeactivateTracking(
     switch($action) {
     case 'activate':
         $legend = __('Activate tracking for %s');
-        $hidden = "submit_activate_now";
+        $value = "activate_now";
         $button = __('Activate now');
         break;
     case 'deactivate':
         $legend = __('Deactivate tracking for %s');
-        $hidden = "submit_deactivate_now";
+        $value = "deactivate_now";
         $button = __('Deactivate now');
         break;
     default:
         $legend = '';
-        $hidden = '';
+        $value = '';
         $button = '';
     }
 
@@ -181,7 +220,7 @@ function PMA_getHtmlForActivateDeactivateTracking(
     );
     $html .= '</legend>';
     $html .= '<input type="hidden" name="version" value="' . $last_version . '" />';
-    $html .= '<input type="hidden" name="' . $hidden . '" value="1" />';
+    $html .= '<input type="hidden" name="toggle_activation" value="' . $value . '" />';
     $html .= '<input type="submit" value="' . $button . '" />';
     $html .= '</fieldset>';
     $html .= '</form>';
@@ -211,27 +250,33 @@ function PMA_getListOfVersionsOfTable()
 /**
  * Function to get html for displaying last version number
  *
- * @param array  $sql_result   sql result
- * @param int    $last_version last version
- * @param array  $url_params   url parameters
- * @param string $url_query    url query
+ * @param array  $sql_result    sql result
+ * @param int    $last_version  last version
+ * @param array  $url_params    url parameters
+ * @param string $url_query     url query
+ * @param string $pmaThemeImage path to theme's image folder
+ * @param string $text_dir      text direction
  *
  * @return string
  */
-function PMA_getHtmlForTableVersionDetails($sql_result, $last_version, $url_params,
-    $url_query
+function PMA_getHtmlForTableVersionDetails(
+    $sql_result, $last_version, $url_params,
+    $url_query, $pmaThemeImage, $text_dir
 ) {
     $tracking_active = false;
 
-    $html = '<table id="versions" class="data">';
+    $html  = '<form method="post" action="tbl_tracking.php" name="versionsForm"'
+        . ' id="versionsForm" class="ajax">';
+    $html .= PMA_URL_getHiddenInputs($GLOBALS['db'], $GLOBALS['table']);
+    $html .= '<table id="versions" class="data">';
     $html .= '<thead>';
     $html .= '<tr>';
-    $html .= '<th>' . __('Database') . '</th>';
-    $html .= '<th>' . __('Table') . '</th>';
+    $html .= '<th></th>';
     $html .= '<th>' . __('Version') . '</th>';
     $html .= '<th>' . __('Created') . '</th>';
     $html .= '<th>' . __('Updated') . '</th>';
     $html .= '<th>' . __('Status') . '</th>';
+    $html .= '<th>' . __('Action') . '</th>';
     $html .= '<th>' . __('Show') . '</th>';
     $html .= '</tr>';
     $html .= '</thead>';
@@ -239,6 +284,10 @@ function PMA_getHtmlForTableVersionDetails($sql_result, $last_version, $url_para
 
     $style = 'odd';
     $GLOBALS['dbi']->dataSeek($sql_result, 0);
+    $delete = PMA_Util::getIcon('b_drop.png', __('Delete version'));
+    $report = PMA_Util::getIcon('b_report.png', __('Tracking report'));
+    $structure = PMA_Util::getIcon('b_props.png', __('Structure snapshot'));
+
     while ($version = $GLOBALS['dbi']->fetchArray($sql_result)) {
         if ($version['version'] == $last_version) {
             if ($version['tracking_active'] == 1) {
@@ -247,28 +296,41 @@ function PMA_getHtmlForTableVersionDetails($sql_result, $last_version, $url_para
                 $tracking_active = false;
             }
         }
+        $delete_link = 'tbl_tracking.php' . $url_query . '&amp;version='
+            . htmlspecialchars($version['version'])
+            . '&amp;submit_delete_version=true';
+        $checkbox_id = 'selected_versions_' . htmlspecialchars($version['version']);
+
         $html .= '<tr class="noclick ' . $style . '">';
-        $html .= '<td>' . htmlspecialchars($version['db_name']) . '</td>';
-        $html .= '<td>' . htmlspecialchars($version['table_name']) . '</td>';
-        $html .= '<td>' . htmlspecialchars($version['version']) . '</td>';
+        $html .= '<td class="center">';
+        $html .= '<input type="checkbox" name="selected_versions[]"'
+            . ' class="checkall" id="' . $checkbox_id . '"'
+            . ' value="' . htmlspecialchars($version['version']) . '"/>';
+        $html .= '</td>';
+        $html .= '<th class="floatright">';
+        $html .= '<label for="' . $checkbox_id . '">'
+            . htmlspecialchars($version['version']) . '</label>';
+        $html .= '</th>';
         $html .= '<td>' . htmlspecialchars($version['date_created']) . '</td>';
         $html .= '<td>' . htmlspecialchars($version['date_updated']) . '</td>';
         $html .= '<td>' . PMA_getVersionStatus($version) . '</td>';
+        $html .= '<td><a class="delete_version_anchor ajax"'
+            . ' href="' . $delete_link . '" >' . $delete . '</a></td>';
         $html .= '<td><a href="tbl_tracking.php';
         $html .= PMA_URL_getCommon(
             $url_params + array(
                 'report' => 'true', 'version' => $version['version']
             )
         );
-        $html .= '">' . __('Tracking report') . '</a>';
-        $html .= '&nbsp;|&nbsp;';
+        $html .= '">' . $report . '</a>';
+        $html .= '&nbsp;&nbsp;';
         $html .= '<a href="tbl_tracking.php';
         $html .= PMA_URL_getCommon(
             $url_params + array(
                 'snapshot' => 'true', 'version' => $version['version']
             )
         );
-        $html .= '">' . __('Structure snapshot') . '</a>';
+        $html .= '">' . $structure . '</a>';
         $html .= '</td>';
         $html .= '</tr>';
 
@@ -282,6 +344,14 @@ function PMA_getHtmlForTableVersionDetails($sql_result, $last_version, $url_para
     $html .= '</tbody>';
     $html .= '</table>';
 
+    $html .= PMA_Util::getWithSelected($pmaThemeImage, $text_dir, "versionsForm");
+    $html .= PMA_Util::getButtonOrImage(
+        'submit_mult', 'mult_submit', 'submit_mult_delete_version',
+        __('Delete version'), 'b_drop.png', 'delete_version'
+    );
+
+    $html .= '</form>';
+
     if ($tracking_active) {
         $html .= PMA_getHtmlForActivateDeactivateTracking(
             'deactivate', $url_query, $last_version
@@ -340,7 +410,7 @@ function PMA_getSQLResultForSelectableTables()
 function PMA_getHtmlForSelectableTables($selectable_tables_sql_result, $url_query)
 {
     $html = '<form method="post" action="tbl_tracking.php' . $url_query . '">';
-    $html .= '<select name="table">';
+    $html .= '<select name="table" class="autosubmit">';
     while ($entries = $GLOBALS['dbi']->fetchArray($selectable_tables_sql_result)) {
         if (PMA_Tracker::isTracked($entries['db_name'], $entries['table_name'])) {
             $status = ' (' . __('active') . ')';
@@ -359,7 +429,6 @@ function PMA_getHtmlForSelectableTables($selectable_tables_sql_result, $url_quer
     }
     $html .= '</select>';
     $html .= '<input type="hidden" name="show_versions_submit" value="1" />';
-    $html .= '<input type="submit" value="' . __('Show versions') . '" />';
     $html .= '</form>';
 
     return $html;
@@ -645,13 +714,14 @@ function PMA_getHtmlForOneStatement($entry, $filter_users,
         && (in_array('*', $filter_users) || $filtered_user)
     ) {
         $html = '<tr class="noclick ' . $style . '">';
-        $html .= '<td><small>' . $line_number . '</small></td>';
+        $html .= '<td class="right"><small>' . $line_number . '</small></td>';
         $html .= '<td><small>'
             . htmlspecialchars($entry['date']) . '</small></td>';
         $html .= '<td><small>'
             . htmlspecialchars($entry['username']) . '</small></td>';
         $html .= '<td>' . $statement . '</td>';
-        $html .= '<td class="nowrap"><a href="tbl_tracking.php'
+        $html .= '<td class="nowrap"><a  class="delete_entry_anchor ajax"'
+            . ' href="tbl_tracking.php'
             . PMA_URL_getCommon(
                 $url_params + array(
                     'report' => 'true',
@@ -719,7 +789,7 @@ function PMA_getHtmlForDataStatements($data, $filter_users,
     $html .= '<th width="100">' . __('Date') . '</th>';
     $html .= '<th width="60">' . __('Username') . '</th>';
     $html .= '<th>' . $header_message . '</th>';
-    $html .= '<th>' . __('Delete') . '</th>';
+    $html .= '<th>' . __('Action') . '</th>';
     $html .= '</tr>';
     $html .= '</thead>';
     $html .= '<tbody>';
@@ -963,72 +1033,54 @@ function PMA_deleteTrackingReportRows(&$data)
     $html = '';
     if (isset($_REQUEST['delete_ddlog'])) {
         // Delete ddlog row data
-        $html .= PMA_handleDeleteDataDefinitionsLog($data);
+        $html .= PMA_deleteFromTrackingReportLog(
+            $data,
+            'ddlog',
+            'DDL',
+            __('Tracking data definition successfully deleted')
+        );
     }
 
     if (isset($_REQUEST['delete_dmlog'])) {
         // Delete dmlog row data
-        $html .= PMA_handleDeleteDataManipulationLog($data);
+        $html .= PMA_deleteFromTrackingReportLog(
+            $data,
+            'dmlog',
+            'DML',
+            __('Tracking data manipulation successfully deleted')
+        );
     }
     return $html;
 }
 
 /**
- * Function to handle the delete ddlog row data
+ * Function to delete from a tracking report log
  *
- * @param array &$data tracked data
+ * @param array  &$data     tracked data
+ * @param string $which_log ddlog|dmlog
+ * @param string $type      DDL|DML
+ * @param string $message   success message
  *
  * @return string HTML for the message
  */
-function PMA_handleDeleteDataDefinitionsLog(&$data)
+function PMA_deleteFromTrackingReportLog(&$data, $which_log, $type, $message)
 {
     $html = '';
-    $delete_id = $_REQUEST['delete_ddlog'];
+    $delete_id = $_REQUEST['delete_' . $which_log];
 
-    // Only in case of valable id
+    // Only in case of valid id
     if ($delete_id == (int)$delete_id) {
-        unset($data['ddlog'][$delete_id]);
+        unset($data[$which_log][$delete_id]);
 
         $successfullyDeleted = PMA_Tracker::changeTrackingData(
-            $_REQUEST['db'], $_REQUEST['table'],
-            $_REQUEST['version'], 'DDL', $data['ddlog']
+            $_REQUEST['db'],
+            $_REQUEST['table'],
+            $_REQUEST['version'],
+            $type,
+            $data[$which_log]
         );
         if ($successfullyDeleted) {
-            $msg = PMA_Message::success(
-                __('Tracking data definition successfully deleted')
-            );
-        } else {
-            $msg = PMA_Message::rawError(__('Query error'));
-        }
-        $html .= $msg->getDisplay();
-    }
-    return $html;
-}
-
-/**
- * Function to handle the delete of fmlog rows
- *
- * @param array &$data tracked data
- *
- * @return string HTML for the message
- */
-function PMA_handleDeleteDataManipulationLog(&$data)
-{
-    $html = '';
-    $delete_id = $_REQUEST['delete_dmlog'];
-
-    // Only in case of valable id
-    if ($delete_id == (int)$delete_id) {
-        unset($data['dmlog'][$delete_id]);
-
-        $successfullyDeleted = PMA_Tracker::changeTrackingData(
-            $_REQUEST['db'], $_REQUEST['table'],
-            $_REQUEST['version'], 'DML', $data['dmlog']
-        );
-        if ($successfullyDeleted) {
-            $msg = PMA_Message::success(
-                __('Tracking data manipulation successfully deleted')
-            );
+            $msg = PMA_Message::success($message);
         } else {
             $msg = PMA_Message::rawError(__('Query error'));
         }
@@ -1066,6 +1118,7 @@ function PMA_exportAsSQLDump($entries)
         __('SQL statements exported. Please copy the dump or execute it.')
     );
     $html .= $msg->getDisplay();
+
     $db_temp = $GLOBALS['db'];
     $table_temp = $GLOBALS['table'];
 
@@ -1200,6 +1253,15 @@ function PMA_getTrackingSet()
     if (isset($_REQUEST['drop_table']) && $_REQUEST['drop_table'] == true) {
         $tracking_set .= 'DROP TABLE,';
     }
+    if (isset($_REQUEST['alter_view']) && $_REQUEST['alter_view'] == true) {
+        $tracking_set .= 'ALTER VIEW,';
+    }
+    if (isset($_REQUEST['create_view']) && $_REQUEST['create_view'] == true) {
+        $tracking_set .= 'CREATE VIEW,';
+    }
+    if (isset($_REQUEST['drop_view']) && $_REQUEST['drop_view'] == true) {
+        $tracking_set .= 'DROP VIEW,';
+    }
     if (isset($_REQUEST['create_index']) && $_REQUEST['create_index'] == true) {
         $tracking_set .= 'CREATE INDEX,';
     }
@@ -1223,6 +1285,35 @@ function PMA_getTrackingSet()
     return $tracking_set;
 }
 
+/**
+ * Deletes a tracking version
+ *
+ * @param string $version tracking version
+ *
+ * @return string HTML of the success message
+ */
+function PMA_deleteTrackingVersion($version)
+{
+    $html = '';
+    $versionDeleted = PMA_Tracker::deleteTracking(
+        $GLOBALS['db'],
+        $GLOBALS['table'],
+        $version
+    );
+    if ($versionDeleted) {
+        $msg = PMA_Message::success(
+            sprintf(
+                __('Version %1$s of %2$s was deleted.'),
+                htmlspecialchars($version),
+                htmlspecialchars($GLOBALS['db'] . '.' . $GLOBALS['table'])
+            )
+        );
+        $html .= $msg->getDisplay();
+    }
+
+    return $html;
+}
+
 /**
  * Function to create the tracking version
  *
@@ -1254,6 +1345,28 @@ function PMA_createTrackingVersion()
     return $html;
 }
 
+/**
+ * Create tracking version for multiple tables
+ *
+ * @param array $selected list of selected tables
+ *
+ * @return void
+ */
+function PMA_createTrackingForMultipleTables($selected)
+{
+    $tracking_set = PMA_getTrackingSet();
+
+    foreach ($selected as $selected_table) {
+        PMA_Tracker::createVersion(
+            $GLOBALS['db'],
+            $selected_table,
+            $_REQUEST['version'],
+            $tracking_set,
+            PMA_Table::isView($GLOBALS['db'], $selected_table)
+        );
+    }
+}
+
 /**
  * Function to get the entries
  *
